<?php

namespace Drupal\uniconsent_cmp\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class UniConsentSettingsForm extends ConfigFormBase {

  const SETTINGS = 'uniconsent_cmp.settings';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'uniconsent_cmp_license';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config(static::SETTINGS);

    $form['is_enable'] = [
      '#type'          => 'checkbox',
      '#title'         => $this->t('Enable UniConsent CMP on the site.'),
      '#default_value' => $config->get('is_enable') ? $config->get('is_enable') : 0,
    ];

    $form['uniconsent_cmp_license'] = [
      '#type' => 'textfield',
      '#title' => $this->t('License ID'),
      '#default_value' => $config->get('uniconsent_cmp_license'),
      '#size' => 60,
      '#required'      => TRUE,
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save Settings'),
    ];
    return $form;
  }

  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);

    $uniconsent_cmp_license = $form_state->getValue('uniconsent_cmp_license');
    if (strpos($uniconsent_cmp_license, 'license-') !== 0) {
      $form_state->setErrorByName('uniconsent_cmp_license', $this->t('The license ID is not valid.'));
    }
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->configFactory->getEditable(static::SETTINGS)
      ->set('is_enable', $form_state->getValue('is_enable'))
      ->set('uniconsent_cmp_license', $form_state->getValue('uniconsent_cmp_license'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
